@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PlainConverter.h 469 2005-07-19 00:23:53Z svn $
+ * $Id: PlainConverter.h 506 2005-08-23 22:04:02Z svn $
  *****************************************************************************/
 
 #ifndef PLAINCONVERTER_H
@@ -61,7 +61,7 @@ private:
                                  const char *code);
     apr_filetype_e get_file_type(const char *path);
 
-    const apr_pool_t *pool_;
+    apr_pool_t *pool_;
 };
 
 #endif
